# yashas_maths

`yashas_maths` is a simple Python package that provides basic arithmetic operations such as addition, subtraction, multiplication, division, exponentiation, modulo, and floor division.

## Installation

You can install the package using:

```bash
pip install yashas_maths
